# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

additionalHeaders: Optional[str]

basePath: Optional[str]

clientId: Optional[str]

clientSecret: Optional[str]

clientTimeout: int
"""
Timeout (in seconds) of the Keycloak client
"""

initialLogin: Optional[bool]
"""
Whether or not to login to Keycloak instance on provider initialization
"""

password: Optional[str]

realm: Optional[str]

redHatSso: Optional[bool]
"""
When true, the provider will treat the Keycloak instance as a Red Hat SSO server, specifically when parsing the version
returned from the /serverinfo API endpoint.
"""

rootCaCertificate: Optional[str]
"""
Allows x509 calls using an unknown CA certificate (for development purposes)
"""

tlsInsecureSkipVerify: Optional[bool]
"""
Allows ignoring insecure certificates when set to true. Defaults to false. Disabling security check is dangerous and
should be avoided.
"""

url: Optional[str]
"""
The base URL of the Keycloak instance, before `/auth`
"""

username: Optional[str]

